@@ -1,4 +1,5 @@
 from actionpack import Action
+from actionpack import KeyedProcedure
 from actionpack import Procedure
 from tests.actionpack import FakeAction
 
@@ -14,9 +15,10 @@ class ProcedureTest(TestCase):
         return isinstance(x, Iterable)
 
     def setUp(self):
-        success = FakeAction()
-        failure = FakeAction(exception=Exception('something went wrong :/'))
-        self.procedure = Procedure(success, failure)
+        self.success = FakeAction(name='success')
+        self.failure = FakeAction(name='failure',
+                                  exception=Exception('something went wrong :/'))
+        self.procedure = Procedure(self.success, self.failure)
 
     def test_Procedure_is_Iterable_of_Actions(self):
         self.assertIsIterable(self.procedure)
@@ -31,5 +33,19 @@ class ProcedureTest(TestCase):
         self.assertIsInstance(next(results), Right)
         self.assertIsInstance(next(results), Left)
 
+    def test_can_validate_Procedure(self):
+        with self.assertRaises(Procedure.NotAnAction):
+            Procedure('wut.', self.failure).validate()
+
     # TODO (withtwoemms) -- add concurrency tests
 
+    def test_can_create_KeyedProcedure(self):
+        results = KeyedProcedure(self.success, self.failure).execute()
+        results_dict = dict(results)
+
+        self.assertIsInstance(results_dict[self.success.name], Right)
+
+    def test_can_validate_KeyedProcedure(self):
+        with self.assertRaises(KeyedProcedure.UnnamedAction):
+            KeyedProcedure(FakeAction(), self.failure)
+
